"""Make pytest-embedded plugin work with the Wokwi CLI."""

WOKWI_CLI_MINIMUM_VERSION = '0.10.1'

from .dut import WokwiDut  # noqa
from .wokwi_cli import WokwiCLI  # noqa

__all__ = [
    'WOKWI_CLI_MINIMUM_VERSION',
    'WokwiCLI',
    'WokwiDut',
]

__version__ = '1.11.2'



import typing as t
from pathlib import Path

if t.TYPE_CHECKING:
    from pytest_embedded_arduino.app import ArduinoApp


class ArduinoFirmwareResolver:
    """
    ArduinoFirmwareResolver class
    """

    def resolve_firmware(self, app: 'ArduinoApp'):
        # get path of ino.bin file
        return Path(app.binary_path, app.sketch + '.ino.bin')
